==> coreboot_24.02~dfsg.orig.tar.xz: coreboot-24.02~dfsg/src/mainboard/lenovo/haswell/variants/t440p/hda_verb.c <==
/* SPDX-License-Identifier: GPL-2.0-only */

#include <device/azalia_device.h>

const u32 cim_verb_data[] = {
	0x10ec0292,	/* Codec Vendor / Device ID: Realtek ALC292 */
	0x17aa220e,	/* Subsystem ID */
	32,		/* Number of 4 dword sets */
	AZALIA_SUBVENDOR(0, 0x17aa220e),
	AZALIA_RESET(1),
	AZALIA_PIN_CFG(0, 0x12, 0x90a60130),
	AZALIA_PIN_CFG(0, 0x13, 0x40000000),
	AZALIA_PIN_CFG(0, 0x14, 0x90170110),
	AZALIA_PIN_CFG(0, 0x15, 0x0321101f),
	AZALIA_PIN_CFG(0, 0x16, 0x411111f0),
	AZALIA_PIN_CFG(0, 0x18, 0x411111f0),
	AZALIA_PIN_CFG(0, 0x19, 0x411111f0),
	AZALIA_PIN_CFG(0, 0x1a, 0x03a11020),
	AZALIA_PIN_CFG(0, 0x1b, 0x411111f0),
	AZALIA_PIN_CFG(0, 0x1d, 0x40738105),
	AZALIA_PIN_CFG(0, 0x1e, 0x411111f0),

	0x05350000, 0x0534601a, 0x05450000, 0x05442000,
	0x05350003, 0x05341ef8, 0x05450003, 0x05441ef8,
	0x05350016, 0x05341ee1, 0x05450016, 0x05441ee1,
	0x05350023, 0x05341f7b, 0x05450023, 0x05441f7b,
	0x05350030, 0x05341fbd, 0x05450030, 0x05441fbd,
	0x05350000, 0x0534e01a, 0x05450030, 0x05441fbd,
	0x02050020, 0x02048014, 0x02050020, 0x02040014,
	0x05350000, 0x0534e01a, 0x05450000, 0x0544e01a,
	0x0205001c, 0x02046800, 0x0205006d, 0x0204aa10,
	0x02050076, 0x02040009, 0x0205006b, 0x02045029,
	0x0205006c, 0x0204a400, 0x02050018, 0x02047208,
	0x0205001a, 0x02049ad2, 0x02050014, 0x02040710,
	0x02050079, 0x02040b40, 0x02050070, 0x02048800,
	0x00b3f410, 0x00c3f11f, 0x00c3f001, 0x015707c0,
	0x0153b080, 0x01470740, 0x0143b000, 0x02050004,
	0x02040080, 0x01470c02, 0x000f0000, 0x000f0000,
	0x02050029, 0x02040050, 0x02050025, 0x0204ebc2,
	0x02050026, 0x02044028, 0x02050029, 0x02040250,
	0x000f0000, 0x000f0000, 0x02050005, 0x0204ff1f,
};

const u32 pc_beep_verbs[0] = {};

AZALIA_ARRAY_SIZES;

==> coreboot-25.03.tar.xz: coreboot-25.03/src/mainboard/lenovo/haswell/variants/t440p/hda_verb.c <==
/* SPDX-License-Identifier: GPL-2.0-only */

#include <device/azalia_device.h>

const u32 cim_verb_data[] = {
	0x10ec0292,	/* Codec Vendor / Device ID: Realtek ALC292 */
	0x17aa220e,	/* Subsystem ID */
	32,		/* Number of 4 dword sets */
	AZALIA_SUBVENDOR(0, 0x17aa220e),
	AZALIA_RESET(1),
	AZALIA_PIN_CFG(0, 0x12, 0x90a60130),
	AZALIA_PIN_CFG(0, 0x13, 0x40000000),
	AZALIA_PIN_CFG(0, 0x14, 0x90170110),
	AZALIA_PIN_CFG(0, 0x15, 0x0321101f),
	AZALIA_PIN_CFG(0, 0x16, AZALIA_PIN_CFG_NC(0)),
	AZALIA_PIN_CFG(0, 0x18, AZALIA_PIN_CFG_NC(0)),
	AZALIA_PIN_CFG(0, 0x19, AZALIA_PIN_CFG_NC(0)),
	AZALIA_PIN_CFG(0, 0x1a, 0x03a11020),
	AZALIA_PIN_CFG(0, 0x1b, AZALIA_PIN_CFG_NC(0)),
	AZALIA_PIN_CFG(0, 0x1d, 0x40738105),
	AZALIA_PIN_CFG(0, 0x1e, AZALIA_PIN_CFG_NC(0)),

	0x05350000, 0x0534601a, 0x05450000, 0x05442000,
	0x05350003, 0x05341ef8, 0x05450003, 0x05441ef8,
	0x05350016, 0x05341ee1, 0x05450016, 0x05441ee1,
	0x05350023, 0x05341f7b, 0x05450023, 0x05441f7b,
	0x05350030, 0x05341fbd, 0x05450030, 0x05441fbd,
	0x05350000, 0x0534e01a, 0x05450030, 0x05441fbd,
	0x02050020, 0x02048014, 0x02050020, 0x02040014,
	0x05350000, 0x0534e01a, 0x05450000, 0x0544e01a,
	0x0205001c, 0x02046800, 0x0205006d, 0x0204aa10,
	0x02050076, 0x02040009, 0x0205006b, 0x02045029,
	0x0205006c, 0x0204a400, 0x02050018, 0x02047208,
	0x0205001a, 0x02049ad2, 0x02050014, 0x02040710,
	0x02050079, 0x02040b40, 0x02050070, 0x02048800,
	0x00b3f410, 0x00c3f11f, 0x00c3f001, 0x015707c0,
	0x0153b080, 0x01470740, 0x0143b000, 0x02050004,
	0x02040080, 0x01470c02, 0x000f0000, 0x000f0000,
	0x02050029, 0x02040050, 0x02050025, 0x0204ebc2,
	0x02050026, 0x02044028, 0x02050029, 0x02040250,
	0x000f0000, 0x000f0000, 0x02050005, 0x0204ff1f,
};

const u32 pc_beep_verbs[0] = {};

AZALIA_ARRAY_SIZES;
